@@ -4,9 +4,7 @@
  * @file		iutest_switch_core.hpp
  * @brief		コア機能定義切り替え ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -78,7 +76,7 @@
 #define GTEST_TEST_				IUTEST_TEST_
 
 
-#else	// !defined(IUTEST_USE_GTEST)
+#else // !defined(IUTEST_USE_GTEST)
 
 //======================================================================
 // undef
@@ -167,7 +165,7 @@
 
 
 // __analysis_assume
-#if defined(_MSC_VER) && _MSC_VER >= 1500
+#if defined(_MSC_VER) && (_MSC_VER >= 1500) && !defined(__CUDACC__)
 
 #define IUTEST_THROUGH_ANALYSIS_ASSUME(expr, todo)					\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_									\
@@ -184,6 +182,6 @@
 
 #endif
 
-#endif	// !defined(IUTEST_USE_GTEST)
+#endif // !defined(IUTEST_USE_GTEST)
 
-#endif	// INCG_IRIS_IUTEST_SWITCH_CORE_HPP_0385C393_90D3_4B06_A027_4B07A17A33CB_
+#endif // INCG_IRIS_IUTEST_SWITCH_CORE_HPP_0385C393_90D3_4B06_A027_4B07A17A33CB_
