@@ -4,9 +4,7 @@
  * @file		iutest_core_impl.hpp
  * @brief		iris unit test UnitTest 実装 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -28,6 +26,7 @@ namespace iutest
 
 //======================================================================
 // class
+/** @private */
 class UnitTestImpl
 {
 protected:
@@ -46,7 +45,7 @@ public:
 	/**
 	 * @brief	テスト中のテストの TestResult の取得
 	*/
-	static TestResult*	current_test_result(void);
+	static TestResult* current_test_result(void);
 
 public:
 	/**
@@ -68,7 +67,7 @@ public:
 public:
 	/** @private */
 	template<typename T>
-	TestCase*	AddTestCase(const char* testcase_name, TestTypeId id, SetUpMethod setup, TearDownMethod teardown
+	TestCase* AddTestCase(const char* testcase_name, TestTypeId id, SetUpMethod setup, TearDownMethod teardown
 		IUTEST_APPEND_EXPLICIT_TEMPLATE_TYPE_(T)
 		)
 	{
@@ -91,27 +90,27 @@ protected:
 	/**
 	 * @brief	テストのリストアップ
 	*/
-	int		Listup(void) const;
+	int Listup(void) const;
 
 	/**
 	 * @brief	テストのリストアップ(with where)
 	*/
-	int		ListupWithWhere(void) const;
+	int ListupWithWhere(void) const;
 
 	/**
 	 * @brief	事前処理
 	*/
-	bool	PreRunner(void);
+	bool PreRunner(void);
 
 	/**
 	 * @brief	テスト結果のクリア
 	*/
-	void	ClearNonAdHocTestResult(void);
+	void ClearNonAdHocTestResult(void);
 
 	/**
 	 * @brief	ad_hoc_testresult のクリア
 	*/
-	void	ClearAdHocTestResult(void)
+	void ClearAdHocTestResult(void)
 	{
 		m_ad_hoc_testresult.Clear();
 	}
@@ -120,21 +119,21 @@ private:
 	/**
 	 * @brief	RecordProperty
 	*/
-	static 	void RecordProperty(const TestProperty& prop);
+	static void RecordProperty(const TestProperty& prop);
 
 private:
 	/**
 	 * @brief	セットアップ
 	*/
-	void	InitializeImpl(void)
+	void InitializeImpl(void)
 	{
 #if IUTEST_HAS_SEH
 
-#if !defined(IUTEST_OS_WINDOWS_MOBILE)
+#if !defined(IUTEST_OS_WINDOWS_MOBILE) && !defined(IUTEST_OS_WINDOWS_PHONE)
 		SetErrorMode(SEM_FAILCRITICALERRORS | SEM_NOALIGNMENTFAULTEXCEPT | SEM_NOGPFAULTERRORBOX | SEM_NOOPENFILEERRORBOX);
 #endif
 
-#if	(defined(_MSC_VER) || IUTEST_OS_WINDOWS_MINGW) && !defined(IUTEST_OS_WINDOWS_MOBILE)
+#if (defined(_MSC_VER) || IUTEST_OS_WINDOWS_MINGW) && !defined(IUTEST_OS_WINDOWS_MOBILE)
 		_set_error_mode(_OUT_TO_STDERR);
 #endif
 
@@ -154,7 +153,7 @@ private:
 	/**
 	 * @brief	後片付け
 	*/
-	void	TerminateImpl(void);
+	void TerminateImpl(void);
 
 private:
 #if IUTEST_HAS_EXCEPTIONS && (defined(_MSC_VER) && (_MSC_VER >= 1400)) && !defined(IUTEST_OS_WINDOWS_MOBILE)
@@ -252,4 +251,4 @@ template<typename T>
 #  include "../impl/iutest_core_impl.ipp"
 #endif
 
-#endif	// INCG_IRIS_IUTEST_CORE_IMPL_HPP_D5ABC7DE_C751_4AC0_922F_547880163891_
+#endif // INCG_IRIS_IUTEST_CORE_IMPL_HPP_D5ABC7DE_C751_4AC0_922F_547880163891_
