@@ -4,9 +4,7 @@
  * @file		iutest_port.hpp
  * @brief		iris unit test 依存関数 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -25,7 +23,7 @@
 
 #include "iutest_internal_defs.hpp"
 
-#if defined(IUTEST_OS_LINUX) || defined(IUTEST_OS_CYGWIN)
+#if defined(IUTEST_OS_LINUX) || defined(IUTEST_OS_CYGWIN) || defined(IUTEST_OS_MAC)
 #  include <unistd.h>
 #  include <locale.h>
 #endif
@@ -39,8 +37,8 @@ namespace nacl
 /**
  * @brief	printf
 */
-void	vprint_message(const char *fmt, va_list va);
-void	print_message(const char *fmt, ...);
+void vprint_message(const char *fmt, va_list va);
+void print_message(const char *fmt, ...);
 
 }
 #endif
@@ -65,7 +63,7 @@ inline void Abort(void) { abort(); }
 
 }	// end of namespace posix
 
-inline void SleepMilliseconds(int n)	{ posix::SleepMillisec(static_cast<unsigned int>(n)); }
+inline void SleepMilliseconds(int n) { posix::SleepMillisec(static_cast<unsigned int>(n)); }
 
 }	// end of namespace internal
 
@@ -141,7 +139,7 @@ class IUTestLog
 public:
 	enum Level
 	{
-		LOG_INFO
+		  LOG_INFO
 		, LOG_WARNING
 		, LOG_ERROR
 		, LOG_FATAL
@@ -176,4 +174,4 @@ private:
 #  include "../impl/iutest_port.ipp"
 #endif
 
-#endif	// INCG_IRIS_IUTEST_PORT_HPP_7893F685_A1A9_477A_82E8_BF06237697FF_
+#endif // INCG_IRIS_IUTEST_PORT_HPP_7893F685_A1A9_477A_82E8_BF06237697FF_
