@@ -4,9 +4,7 @@
  * @file		iutest_string.hpp
  * @brief		iris unit test 文字列操作 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -31,9 +29,9 @@
 #if defined(IUTEST_OS_CYGWIN)
 #include <strings.h>
 #endif
-#if		IUTEST_HAS_STRINGSTREAM
+#if   IUTEST_HAS_STRINGSTREAM
 #  include <sstream>
-#elif	IUTEST_HAS_STRSTREAM
+#elif IUTEST_HAS_STRSTREAM
 #  include <strstream>
 #endif
 
@@ -43,36 +41,15 @@ namespace iutest {
 namespace detail
 {
 
-//======================================================================
-// function
-/*
- * 今のところ使っていない
-
-static char*			xcsstr(char* src, const char* substr)				{ return strstr(src, substr); }
-static const char*		xcsstr(const char* src, const char* substr)			{ return strstr(src, substr); }
-static char*			xcschr(char* src, char ch)							{ return strchr(src, ch); }
-static const char*		xcschr(const char* src, char ch)					{ return strchr(src, ch); }
-static int				xcscmp(const char* str1, const char* str2)			{ return strcmp(str1, str2); }
-static long				xcstol(const char* src, char** end, int radix)		{ return strtol(src, end, radix); }
-
-static wchar_t*			xcsstr(wchar_t* src, const wchar_t* substr)			{ return wcsstr(src, substr); }
-static const wchar_t*	xcsstr(const wchar_t* src, const wchar_t* substr)	{ return wcsstr(src, substr); }
-static wchar_t*			xcschr(wchar_t* src, wchar_t ch)					{ return wcschr(src, ch); }
-static const wchar_t*	xcschr(const wchar_t* src, wchar_t ch)				{ return wcschr(src, ch); }
-static int				xcscmp(const wchar_t* str1, const wchar_t* str2)	{ return wcscmp(str1, str2); }
-static long				xcstol(const wchar_t* src, wchar_t** end, int radix){ return wcstol(src, end, radix); }
-
-*/
-
 /**
  * @internal
  * @brief	stricmp
 */
 inline int iu_stricmp(const char* str1, const char* str2)
 {
-#if	defined(IUTEST_OS_WINDOWS)
+#if defined(IUTEST_OS_WINDOWS)
 
-#if	defined(__BORLANDC__)
+#if defined(__BORLANDC__)
 	return stricmp(str1, str2);
 #else
 	return _stricmp(str1, str2);
@@ -105,9 +82,9 @@ inline int iu_stricmp(const char* str1, const char* str2)
 */
 inline int iu_wcsicmp(const wchar_t * str1, const wchar_t * str2)
 {
-#if		defined(_MSC_VER)
+#if   defined(_MSC_VER)
 	return _wcsicmp(str1, str2);
-#elif	defined(IUTEST_OS_LINUX) && !defined(IUTEST_OS_LINUX_ANDROID)
+#elif defined(IUTEST_OS_LINUX) && !defined(IUTEST_OS_LINUX_ANDROID)
 	return wcscasecmp(str1, str2);
 #else
 	const wchar_t* l = str1;
@@ -128,14 +105,14 @@ inline int iu_wcsicmp(const wchar_t * str1, const wchar_t * str2)
 }
 
 inline bool IsEmpty(const char* p) { return p == NULL || *p == '\0'; }
-inline IUTEST_CXX_CONSTEXPR bool IsSpace(char ch)	{ return ch == ' ' || ch =='\t'; }
-inline IUTEST_CXX_CONSTEXPR const char*	SkipSpace(const char* p)
+inline IUTEST_CXX_CONSTEXPR bool IsSpace(char ch) { return ch == ' ' || ch =='\t'; }
+inline IUTEST_CXX_CONSTEXPR const char* SkipSpace(const char* p)
 {
 IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 	return p == NULL ? NULL : (IsSpace(*p) ? SkipSpace(++p) : p);
 IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
 }
-inline IUTEST_CXX_CONSTEXPR const char*	FindComma(const char* p)
+inline IUTEST_CXX_CONSTEXPR const char* FindComma(const char* p)
 {
 	return (p == NULL || *p == '\0') ? NULL : ((*p == ',') ? p : FindComma(++p));
 }
@@ -192,9 +169,9 @@ template<class _Elem, class _Traits>class iu_basic_stream;
 class iuStringStream
 {
 public:
-#if		IUTEST_HAS_STRINGSTREAM
-	typedef ::std::stringstream	stlstream;
-#elif	IUTEST_HAS_STRSTREAM
+#if   IUTEST_HAS_STRINGSTREAM
+	typedef ::std::stringstream stlstream;
+#elif IUTEST_HAS_STRSTREAM
 IUTEST_PRAGMA_MSC_WARN_PUSH()
 IUTEST_PRAGMA_MSC_WARN_DISABLE(4250)
 	class stlstream : public ::std::strstream
@@ -235,9 +212,9 @@ IUTEST_PRAGMA_MSC_WARN_POP()
 public:
 
 #if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
-	typedef stlstream	type;
+	typedef stlstream type;
 #else
-	typedef iu_stream	type;
+	typedef iu_stream type;
 #endif
 };
 
@@ -260,7 +237,7 @@ class iu_basic_stream
 		struct impl_select
 		{
 			template<typename TA, typename TB>
-			static const TA	constant(const TA a, const TB b)
+			static const TA constant(const TA a, const TB b)
 			{
 				(void)b;
 				return a;
@@ -270,7 +247,7 @@ class iu_basic_stream
 		struct impl_select<TMP, wchar_t>
 		{
 			template<typename TA, typename TB>
-			static const TB	constant(const TA a, const TB b)
+			static const TB constant(const TA a, const TB b)
 			{
 				(void)a;
 				return b;
@@ -278,7 +255,7 @@ class iu_basic_stream
 		};
 
 	public:
-		typedef impl_select<void, T>	select;
+		typedef impl_select<void, T> select;
 	};
 #define IUTEST_PP_XCS(txt_)	xcs<_Elem>::select::constant(txt_, L##txt_)
 
@@ -459,12 +436,25 @@ IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
 }	// end of namespace detail
 
 #if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
-typedef ::std::ostream					iu_ostream;
-typedef std::ostream& (*iu_basic_iomanip)(std::ostream&);
+typedef ::std::ostream iu_ostream;
+typedef ::std::ostream& (*iu_basic_iomanip)(::std::ostream&);
+
 #else
-typedef detail::iuStringStream::type	iu_ostream;
+typedef detail::iuStringStream::type iu_ostream;
+#endif
+
+#if !defined(IUTEST_HAS_BIGGESTINT_OSTREAM)
+#  if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+#    if (defined(_STLPORT_VERSION) && !defined(_STLP_LONG_LONG)) || (defined(_MSC_VER) && _MSC_VER < 1310)
+#      define IUTEST_HAS_BIGGESTINT_OSTREAM		0
+#    endif
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_BIGGESTINT_OSTREAM)
+#  define IUTEST_HAS_BIGGESTINT_OSTREAM			1
 #endif
 
 }	// end of namespace iutest
 
-#endif	// INCG_IRIS_IUTEST_STRING_HPP_E22B02D7_E9E7_412C_B609_DC3D9C66895D_
+#endif // INCG_IRIS_IUTEST_STRING_HPP_E22B02D7_E9E7_412C_B609_DC3D9C66895D_
