@@ -4,9 +4,7 @@
  * @file		iutest_assertion.hpp
  * @brief		iris unit test assertion 定義 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -23,18 +21,22 @@
 #include "iutest_printers.hpp"
 #include "internal/iutest_list.hpp"
 
-namespace iutest_report_result
-{
-	//! TestPartResultReporter がない場合の処理関数
-	void ReportTestPartResult(const ::iutest::TestPartResult& test_part_result);
-}
-
 namespace iutest
 {
 
+//======================================================================
+// typedef
 //! Message クラス
 typedef detail::iuStreamMessage	Message;
 
+//======================================================================
+// declare
+namespace detail
+{
+	//! TestPartResultReporter がない場合の処理関数
+	void DefaultReportTestPartResult(const TestPartResult& test_part_result);
+}
+
 //======================================================================
 // class
 /**
@@ -54,7 +56,12 @@ public:
 	/**
 	 * @brief	成否
 	*/
-	bool	failed(void) const IUTEST_CXX_NOEXCEPT_SPEC { return !m_result; }
+	bool failed(void) const IUTEST_CXX_NOEXCEPT_SPEC { return !m_result; }
+
+	/**
+	 * @brief	成否
+	*/
+	bool passed(void) const IUTEST_CXX_NOEXCEPT_SPEC { return m_result; }
 
 	/**
 	 * @brief	メッセージの取得
@@ -68,36 +75,56 @@ public:
 	const char* failure_message(void) const { return message(); }
 
 	/** @private */
-	IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void)	const { return m_result; }
+	IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void) const { return m_result; }
 
 public:
 	/**
 	 * @brief	メッセージ追加
 	*/
 	template<typename T>
-	AssertionResult& operator << (T value)
+	AssertionResult& operator << (const T& value)
 	{
 		Message msg;
 		msg << value;
 		m_message += msg.GetString();
 		return *this;
 	}
+public:
+	AssertionResult operator ! (void) const
+	{
+		return AssertionResult(failed()) << message();
+	}
+	AssertionResult operator && (const AssertionResult& rhs) const
+	{
+		return AssertionResult(m_result && rhs.passed()) << message() << " && " << rhs.message();
+	}
+	AssertionResult operator || (const AssertionResult& rhs) const
+	{
+		return AssertionResult(m_result || rhs.passed()) << message() << " || " << rhs.message();
+	}
 
 public:
 	/**
 	 * @brief	成功結果の作成
 	*/
-	static AssertionResult	Success(void) { return AssertionResult(true); }
+	static AssertionResult Success(void) { return AssertionResult(true); }
 	/**
 	 * @brief	失敗結果の作成
 	*/
-	static AssertionResult	Failure(void) { return AssertionResult(false); }
+	static AssertionResult Failure(void) { return AssertionResult(false); }
+	/**
+	 * @brief	成否の取得
+	*/
+	template<typename T>
+	static AssertionResult Is(const T& b) { return AssertionResult(b ? true : false); }
+	/** @override */
+	static AssertionResult Is(const AssertionResult& ar) { return AssertionResult(ar); }
 
 private:
 	IUTEST_PP_DISALLOW_ASSIGN(AssertionResult);
 
 	::std::string m_message;
-	bool	m_result;
+	bool m_result;
 };
 
 #if IUTEST_HAS_ASSERTION_RETURN
@@ -167,7 +194,7 @@ private:
 	struct List {
 		static msg_list s_scoped_message;
 	};
-	typedef List<void>	MessageList;
+	typedef List<void> MessageList;
 
 #if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
 	friend class ScopedMessage;
@@ -271,11 +298,11 @@ public:
 #if IUTEST_HAS_ASSERTION_RETURN
 	/** @private */
 	template<typename R>
-	R	operator = (const ReturnTypedFixed<R>& fixed)
+	R operator = (const ReturnTypedFixed<R>& fixed)
 	{
 		this->operator=(fixed.fixed);
 		return fixed.ret.value;
-	}	
+	}
 #endif
 
 private:
@@ -302,8 +329,7 @@ private:
 		}
 		else
 		{
-			using namespace iutest_report_result;
-			ReportTestPartResult(m_part_result);
+			detail::DefaultReportTestPartResult(m_part_result);
 		}
 
 		if( m_part_result.type() != TestPartResult::kSuccess
@@ -453,7 +479,7 @@ public:
 			<< "\nExpected: NULL";
 	}
 	template<typename T>
-	static AssertionResult	CompareNe(const char* expr, const T* val)
+	static AssertionResult CompareNe(const char* expr, const T* val)
 	{
 		if( NULL != val )
 		{
@@ -484,7 +510,7 @@ public:
 };
 
 template<typename T1, typename T2>
-inline AssertionResult	CmpHelperSame(const char* expected_str, const char* actual_str
+inline AssertionResult CmpHelperSame(const char* expected_str, const char* actual_str
 									  , const T1& expected, const T2& actual)
 {
 	if( &expected == &actual )
@@ -660,7 +686,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1,
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
 							   , const char* val1, const char* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 == val2 )
 		{
@@ -679,7 +705,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
 							   , const wchar_t* val1, const wchar_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 == val2 )
 		{
@@ -697,8 +723,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val1 == val2 )
 	{
@@ -710,8 +736,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-																   , const Elem* val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const Elem* val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val2 == val1 )
 	{
@@ -723,8 +749,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const Elem* val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const Elem* val2)
 {
 	if( val1 == val2 )
 	{
@@ -736,9 +762,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 }
 #if IUTEST_HAS_CHAR16_T
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-															   , const char16_t* val1, const char16_t* val2)
+															, const char16_t* val1, const char16_t* val2)
 {
-	if( val1 == NULL && val2 == NULL ) 
+	if( val1 == NULL && val2 == NULL )
 	{
 		return AssertionSuccess();
 	}
@@ -748,9 +774,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 #endif
 #if IUTEST_HAS_CHAR32_T
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
-															   , const char32_t* val1, const char32_t* val2)
+															, const char32_t* val1, const char32_t* val2)
 {
-	if( val1 == NULL && val2 == NULL ) 
+	if( val1 == NULL && val2 == NULL )
 	{
 		return AssertionSuccess();
 	}
@@ -760,9 +786,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 #endif
 
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-							   , const char* val1, const char* val2)
+							, const char* val1, const char* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 != val2 )
 		{
@@ -779,9 +805,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-							   , const wchar_t* val1, const wchar_t* val2)
+							, const wchar_t* val1, const wchar_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 != val2 )
 		{
@@ -799,8 +825,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-															   , const ::std::basic_string<Elem, Traits, Ax>& val1
-															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+															, const ::std::basic_string<Elem, Traits, Ax>& val1
+															, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val1 != val2 )
 	{
@@ -812,8 +838,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-															   , const Elem* val1
-															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+															, const Elem* val1
+															, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	if( val2 != val1 )
 	{
@@ -825,8 +851,8 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-															   , const ::std::basic_string<Elem, Traits, Ax>& val1
-															   , const Elem* val2)
+															, const ::std::basic_string<Elem, Traits, Ax>& val1
+															, const Elem* val2)
 {
 	if( val1 != val2 )
 	{
@@ -838,7 +864,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 }
 #if IUTEST_HAS_CHAR16_T
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-															   , const char16_t* val1, const char16_t* val2)
+															, const char16_t* val1, const char16_t* val2)
 {
 	if( (val1 == NULL || val2 == NULL)
 		&& val1 != val2 )
@@ -851,7 +877,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 #endif
 #if IUTEST_HAS_CHAR32_T
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
-															   , const char32_t* val1, const char32_t* val2)
+															, const char32_t* val1, const char32_t* val2)
 {
 	if( (val1 == NULL || val2 == NULL)
 		&& val1 != val2 )
@@ -864,9 +890,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 #endif
 
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-							   , const char* val1, const char* val2)
+							, const char* val1, const char* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 == val2 )
 		{
@@ -884,9 +910,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* e
 		, true);
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-							   , const wchar_t* val1, const wchar_t* val2)
+							, const wchar_t* val1, const wchar_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 == val2 )
 		{
@@ -905,29 +931,29 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* e
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	return CmpHelperSTRCASEEQ(expr1, expr2, val1.c_str(), val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-																   , const Elem* val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const Elem* val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	return CmpHelperSTRCASEEQ(expr1, expr2, val1, val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const Elem* val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const Elem* val2)
 {
 	return CmpHelperSTRCASEEQ(expr1, expr2, val1.c_str(), val2);
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
-							   , const char* val1, const char* val2)
+							, const char* val1, const char* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 != val2 )
 		{
@@ -944,9 +970,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
-							   , const wchar_t* val1, const wchar_t* val2)
+							, const wchar_t* val1, const wchar_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL || val2 == NULL )
 	{
 		if( val1 != val2 )
 		{
@@ -964,22 +990,22 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	return CmpHelperSTRCASENE(expr1, expr2, val1.c_str(), val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
-																   , const Elem* val1
-																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
+																, const Elem* val1
+																, const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
 	return CmpHelperSTRCASENE(expr1, expr2, val1, val2.c_str());
 }
 template<typename Elem, typename Traits, typename Ax>
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* expr1, const char* expr2
-																   , const ::std::basic_string<Elem, Traits, Ax>& val1
-																   , const Elem* val2)
+																, const ::std::basic_string<Elem, Traits, Ax>& val1
+																, const Elem* val2)
 {
 	return CmpHelperSTRCASENE(expr1, expr2, val1.c_str(), val2);
 }
@@ -987,7 +1013,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 
 template<typename RawType>
 static AssertionResult CmpHelperFloatingPointEQ(const char* expr1, const char* expr2
-							   , RawType val1, RawType val2)
+												, RawType val1, RawType val2)
 {
 	floating_point<RawType> f1(val1), f2(val2);
 	if( f1.AlmostEquals(f2) )
@@ -995,13 +1021,13 @@ static AssertionResult CmpHelperFloatingPointEQ(const char* expr1, const char* e
 		return AssertionSuccess();
 	}
 	return EqFailure(expr1, expr2
-		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
-		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
+		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2)).c_str()
+		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)).c_str());
 }
 
 template<typename RawType>
-static AssertionResult	CmpHelperFloatingPointLE(const char* expr1, const char* expr2
-							   , RawType val1, RawType val2)
+static AssertionResult CmpHelperFloatingPointLE(const char* expr1, const char* expr2
+												, RawType val1, RawType val2)
 {
 	if( val1 < val2 )
 	{
@@ -1013,20 +1039,8 @@ static AssertionResult	CmpHelperFloatingPointLE(const char* expr1, const char* e
 		return AssertionSuccess();
 	}
 	return EqFailure(expr1, expr2
-		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
-		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
-}
-
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ FloatLE(const char* expr1, const char* expr2
-							   , float val1, float val2)
-{
-	return CmpHelperFloatingPointLE<float>(expr1, expr2, val1, val2);
-}
-
-inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleLE(const char* expr1, const char* expr2
-							   , double val1, double val2)
-{
-	return CmpHelperFloatingPointLE<double>(expr1, expr2, val1, val2);
+		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(f1, f2)).c_str()
+		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(f2, f1)).c_str());
 }
 
 #if defined(IUTEST_OS_WINDOWS)
@@ -1054,6 +1068,27 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTFailure(const char* exp
 
 }	// end of namespace internal
 
+/**
+ * @brief	Float LE Formatter
+ * @note	IUTEST_ASSERT_PRED_FORMAT2(::iutest::FloatLE , 0, 1);
+*/
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ FloatLE(const char* expr1, const char* expr2
+	, float val1, float val2)
+{
+	return internal::CmpHelperFloatingPointLE<float>(expr1, expr2, val1, val2);
+}
+
+/**
+ * @brief	Double LE Formatter
+ * @note	IUTEST_ASSERT_PRED_FORMAT2(::iutest::DoubleLE , 0, 1);
+*/
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleLE(const char* expr1, const char* expr2
+	, double val1, double val2)
+{
+	return internal::CmpHelperFloatingPointLE<double>(expr1, expr2, val1, val2);
+}
+
+
 }	// end of namespace iutest
 
-#endif	// INCG_IRIS_IUTEST_ASSERTION_HPP_E6AF3476_DA81_46F7_A961_ACCEF7363932_
+#endif // INCG_IRIS_IUTEST_ASSERTION_HPP_E6AF3476_DA81_46F7_A961_ACCEF7363932_
