@@ -1,21 +1,19 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_printers.hpp
- * @brief		iris unit test print o̓wp[ t@C
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		iris unit test print 出力ヘルパー ファイル
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_printers_HPP_A6A321C9_9279_4336_8167_058C59EC0FD0_
-#define INCG_IRIS_iutest_printers_HPP_A6A321C9_9279_4336_8167_058C59EC0FD0_
+#ifndef INCG_IRIS_IUTEST_PRINTERS_HPP_A6A321C9_9279_4336_8167_058C59EC0FD0_
+#define INCG_IRIS_IUTEST_PRINTERS_HPP_A6A321C9_9279_4336_8167_058C59EC0FD0_
 
 //======================================================================
 // include
@@ -35,6 +33,7 @@ namespace detail
 
 inline void PrintBytesInObjectTo(const unsigned char* buf, size_t size, iu_ostream* os)
 {
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 	const size_t kMaxCount = detail::kValues::MaxPrintContainerCount;
 	*os << size << "-Byte object < ";
 	for( size_t i=0; i < size; ++i )
@@ -47,63 +46,82 @@ inline void PrintBytesInObjectTo(const unsigned char* buf, size_t size, iu_ostre
 		}
 	}
 	*os << ">";
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
 }
 
 namespace printer_internal
 {
 
-/** @private */
-template<typename T>
-class TypeWithoutFormatter
+namespace formatter
 {
-	template<bool convertible, typename DMY>
-	struct impl
+
+/** @private */
+template<bool convertible>
+struct Printer
+{
+	template<typename T>
+	static void Print(const T& value, iu_ostream* os)
 	{
-		static void Print(const T& value, iu_ostream* os)
-		{
-			const unsigned char* ptr = reinterpret_cast<const unsigned char*>(&value);
-			size_t size = sizeof(T);
-			PrintBytesInObjectTo(ptr, size, os);
-		}
-	};
-	template<typename DMY>
-	struct impl<true, DMY>
-	{
-		static void Print(const T& value, iu_ostream* os)
-		{
-			const BiggestInt v = value;
-			*os << v;
-		}
-	};
-public:
-	static void PrintValue(const T& value, iu_ostream* os)
-	{
-		impl<iutest_type_traits::is_convertible<const T&, BiggestInt>::value, void>::Print(value, os);
+		const unsigned char* ptr = reinterpret_cast<const unsigned char*>(&value);
+		const size_t size = sizeof(T);
+		PrintBytesInObjectTo(ptr, size, os);
 	}
 };
 
-#if IUTEST_HAS_STRINGSTREAM
+template<>
+struct Printer<true>
+{
+	template<typename T>
+	static void Print(const T& value, iu_ostream* os)
+	{
+#if IUTEST_HAS_BIGGESTINT_OSTREAM
+		const BiggestInt v = value;
+#else
+		const Int32 v = value;
+#endif
+		*os << v;
+	}
+};
+
+}
+
+/** @private */
+class TypeWithoutFormatter
+{
+public:
+	template<typename T>
+	static void PrintValue(const T& value, iu_ostream* os)
+	{
+		formatter::Printer<iutest_type_traits::is_convertible<const T&, BiggestInt>::value>::Print(value, os);
+	}
+};
+
+#if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
+
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
 template<typename Elem, typename Traits, typename T>
 ::std::basic_ostream<Elem, Traits>& operator << (::std::basic_ostream<Elem, Traits>& os, const T& value)
 {
-	TypeWithoutFormatter<T>::PrintValue(value, &os);
+	TypeWithoutFormatter::PrintValue(value, &os);
 	return os;
 }
 #else
 template<typename T>
 iu_ostream& operator << (iu_ostream& os, const T& value)
 {
-	TypeWithoutFormatter<T>::PrintValue(value, &os);
+	TypeWithoutFormatter::PrintValue(value, &os);
 	return os;
 }
 #endif
 
+#endif
+
 }	// end of printer_internal
 
 namespace printer_internal2
 {
 
-// 
+// 解決順序
 // foo::operator <<
 // ::operator <<
 // ::iutest::detail::printer_internal::operator <<
@@ -119,32 +137,12 @@ void DefaultPrintNonContainerTo(const T& value, iu_ostream* os)
 //======================================================================
 // declare
 template<typename T>
-inline void UniversalPrintTo(T value, iu_ostream* os);
-
-//======================================================================
-// class
-/** @private */
-template<typename T>
-class iuUniversalPrinter
-{
-public:
-	static void Print(const T& value, iu_ostream* os)
-	{
-		UniversalPrintTo(value, os);
-	}
-};
+void UniversalPrint(const T& value, iu_ostream* os);
 
 //======================================================================
 // function
-/** @private */
-template<typename T>
-inline void	UniversalPrint(const T& value, iu_ostream* os)
-{
-	iuUniversalPrinter<T>::Print(value, os);
-}
-
 /**
- * @brief	ftHgϊ֐
+ * @brief	デフォルト文字列変換関数
 */
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::yes_t
@@ -161,24 +159,33 @@ inline void DefaultPrintTo(IsContainerHelper::yes_t
 			*os << ",";
 			if( count == kMaxCount )
 			{
-				*os << "...";
+				*os << " ...";
 				break;
 			}
 		}
 		*os << " ";
 		UniversalPrint(*it, os);
 	}
-	if( count > 0 ) *os << " ";
+	if( count > 0 )
+	{
+		*os << " ";
+	}
 	*os << "}";
 }
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::no_t
-						   , iutest_type_traits::false_type
-						   , const T& value, iu_ostream* os)
+						, iutest_type_traits::false_type
+						, const T& value, iu_ostream* os)
 {
+#if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
 	printer_internal2::DefaultPrintNonContainerTo(value, os);
+#else
+	printer_internal::TypeWithoutFormatter::PrintValue(value, os);
+#endif
 }
 
+#if !defined(IUTEST_NO_SFINAE) && !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+
 template<typename T>
 inline void DefaultPtrPrintTo(T* ptr, iu_ostream* os, typename enable_if_t< is_convertible<T*, const void*> >::type*& = enabler::value)
 {
@@ -189,10 +196,21 @@ inline void DefaultPtrPrintTo(T* ptr, iu_ostream* os, typename disable_if_t< is_
 {
 	*os << reinterpret_cast<const void*>(reinterpret_cast<type_least_t<8>::UInt>(ptr));
 }
+
+#else
+
+template<typename T>
+inline void DefaultPtrPrintTo(T* ptr, iu_ostream* os)
+{
+	*os << reinterpret_cast<const void*>(reinterpret_cast<type_least_t<8>::UInt>(ptr));
+}
+
+#endif
+
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::no_t
-						   , iutest_type_traits::true_type
-						   , T* ptr, iu_ostream* os)
+						, iutest_type_traits::true_type
+						, T* ptr, iu_ostream* os)
 {
 	if( ptr == NULL )
 	{
@@ -205,35 +223,57 @@ inline void DefaultPrintTo(IsContainerHelper::no_t
 }
 
 /**
- * @brief	ϊ֐
+ * @brief	文字列変換関数
 */
 template<typename T>
-inline void PrintTo(const T& value, iu_ostream* os)	{ DefaultPrintTo(IsContainerHelper::IsContainer<T>(0), iutest_type_traits::is_pointer<T>(), value, os); }
+inline void PrintTo(const T& value, iu_ostream* os)	{
+	DefaultPrintTo(
+#if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
+		IsContainerHelper::IsContainer<T>(0)
+#else
+		IsContainerHelper::IsContainer(0, &detail::type<T>())
+#endif
+		, iutest_type_traits::is_pointer<T>(), value, os);
+}
 inline void PrintTo(bool b, iu_ostream* os)			{ *os << (b ? "true" : "false"); }
 inline void PrintTo(const char* c, iu_ostream* os)	{ *os << c; }
 inline void PrintTo(char* c, iu_ostream* os)		{ *os << c; }
 inline void PrintTo(const ::std::string& str, iu_ostream* os)	{ *os << str.c_str(); }
+#if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 template<typename T>
-inline void PrintTo(const floating_point<T>& f, iu_ostream* os)	{ *os << f.raw() << "(" << ToHexString(f.bit()) << ")"; }
+inline void PrintTo(const floating_point<T>& f, iu_ostream* os)	{ *os << f.raw() << "(0x" << ToHexString(f.bit()) << ")"; }
 template<typename T1, typename T2>
 inline void PrintTo(const ::std::pair<T1, T2>& value, iu_ostream* os)
 {
 	*os << "(";
-	iuUniversalPrinter<T1>::Print(value.first, os);
+	UniversalPrint(value.first, os);
 	*os << ", ";
-	iuUniversalPrinter<T2>::Print(value.second, os);
+	UniversalPrint(value.second, os);
 	*os << ")";
 }
-// char or unsigned char ̎ɁA 0  NULL ɂȂȂ悤ɏC
+#endif
+// char or unsigned char の時に、 0 が NULL 文字にならないように修正
 inline void PrintTo(const char value, iu_ostream* os)
 {
-	if( value == 0 ) *os << "\\0";
-	else *os << "\'" << value << "\'";
+	if( value == 0 )
+	{
+		*os << "\\0";
+	}
+	else
+	{
+		*os << "\'" << value << "\'";
+	}
 }
 inline void PrintTo(const wchar_t value, iu_ostream* os)
 {
-	if( value == 0 ) *os << "\\0";
-	else *os << "\'" << value << "\'";
+	if( value == 0 )
+	{
+		*os << "\\0";
+	}
+	else
+	{
+		*os << "\'" << value << "\'";
+	}
 }
 inline void PrintTo(const unsigned char value, iu_ostream* os)
 {
@@ -307,20 +347,23 @@ inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5, A6, A7, A8, A9>& t,
 
 #endif
 
-//======================================================================
-// function
-
 /** @private */
 template<typename T>
-inline void	IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const T& value, iu_ostream* os)
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const T& value, iu_ostream* os)
 {
 	UniversalPrint(value, os);
 }
 
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const char* str, iu_ostream* os)
 {
-	if( str == NULL ) *os << kStrings::Null;
-	else UniversalPrint(::std::string(str), os);
+	if( str == NULL )
+	{
+		*os << kStrings::Null;
+	}
+	else
+	{
+		UniversalPrint(::std::string(str), os);
+	}
 }
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char* str, iu_ostream* os)
 {
@@ -328,8 +371,14 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char* str, iu_ostream*
 }
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const wchar_t* str, iu_ostream* os)
 {
-	if( str == NULL ) *os << kStrings::Null;
-	else UniversalPrint(detail::ShowWideCString(str), os);
+	if( str == NULL )
+	{
+		*os << kStrings::Null;
+	}
+	else
+	{
+		UniversalPrint(detail::ShowWideCString(str), os);
+	}
 }
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(wchar_t* str, iu_ostream* os)
 {
@@ -338,8 +387,14 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(wchar_t* str, iu_ostrea
 #if IUTEST_HAS_CHAR16_T
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const char16_t* str, iu_ostream* os)
 {
-	if( str == NULL ) *os << kStrings::Null;
-	else UniversalPrint(detail::ShowWideCString(str), os);
+	if( str == NULL )
+	{
+		*os << kStrings::Null;
+	}
+	else
+	{
+		UniversalPrint(detail::ShowWideCString(str), os);
+	}
 }
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char16_t* str, iu_ostream* os)
 {
@@ -348,7 +403,7 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char16_t* str, iu_ostre
 #endif
 
 /**
- * @brief	z̏o
+ * @brief	配列の出力
 */
 template<typename T>
 inline void PrintRawArrayTo(const T* a, size_t cnt, iu_ostream* os)
@@ -362,12 +417,15 @@ inline void PrintRawArrayTo(const T* a, size_t cnt, iu_ostream* os)
 }
 
 /**
- * @brief	z̏o
+ * @brief	配列の出力
 */
 template<typename T>
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const T* begin, size_t N, iu_ostream* os)
 {
-	if( N == 0 ) *os << "{}";
+	if( N == 0 )
+	{
+		*os << "{}";
+	}
 	else
 	{
 		*os << "{";
@@ -387,7 +445,7 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const T* begin, size_t
 	}
 }
 /**
- * @brief	z̏o
+ * @brief	配列の出力
 */
 inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const char* begin, size_t N, iu_ostream* os)
 {
@@ -400,27 +458,53 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const wchar_t* begin, s
 	UniversalTersePrint(begin, os);
 }
 
-//======================================================================
-// class
-
 /** @private */
 template<typename T>
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintTo(T value, iu_ostream* os) { PrintTo(value, os); }
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintTo(const T& value, iu_ostream* os)
+{
+	PrintTo(value, os);
+}
+
+//======================================================================
+// class
+/** @private */
+template<typename T>
+class iuUniversalPrinter
+{
+public:
+	static void Print(const T& value, iu_ostream* os)
+	{
+		UniversalPrintTo(value, os);
+	}
+};
+
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 
 /** @private */
 template<typename T, size_t SIZE>
 class iuUniversalPrinter<T[SIZE]>
 {
 public:
-	static void Print(const T (&a)[SIZE], iu_ostream* os)
+	static void Print(const T(&a)[SIZE], iu_ostream* os)
 	{
 		UniversalPrintArray(a, SIZE, os);
 	}
 };
 
-/**
- * @}
-*/
+#endif
+
+//======================================================================
+// function
+/** @private */
+template<typename T>
+inline void UniversalPrint(const T& value, iu_ostream* os)
+{
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+	iuUniversalPrinter<T>::Print(value, os);
+#else
+	UniversalPrintTo(value, os);
+#endif
+}
 
 }	// end of namespace detail
 
@@ -428,23 +512,19 @@ public:
 // function
 
 /**
- * @brief	
+ * @brief	文字列化
 */
 template<typename T>
 inline ::std::string PrintToString(const T& v)
 {
 	detail::iuStringStream::type strm;
-#if 0
-	strm << v;
-#else
 	detail::UniversalTersePrint(v, &strm);
-#endif
 	return strm.str();
 }
 
 #if IUTEST_HAS_VARIADIC_TEMPLATES
 /**
- * @brief	
+ * @brief	文字列化
 */
 template<typename T>
 inline ::std::string PrintToStrings(const char* separate, const T& v)
@@ -453,7 +533,7 @@ inline ::std::string PrintToStrings(const char* separate, const T& v)
 	return PrintToString(v);
 }
 /**
- * @brief	
+ * @brief	文字列化
 */
 template<typename T, typename ...Args>
 inline ::std::string PrintToStrings(const char* separate, const T& v, Args... args)
@@ -467,4 +547,4 @@ inline ::std::string PrintToStrings(const char* separate, const T& v, Args... ar
 
 }	// end of namespace iutest
 
-#endif
+#endif // INCG_IRIS_IUTEST_PRINTERS_HPP_A6A321C9_9279_4336_8167_058C59EC0FD0_
