@@ -1,24 +1,23 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_util_quiet_result_printer.hpp
- * @brief		iris unit test quiet result printer t@C
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		iris unit test quiet result printer ファイル
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_util_quiet_result_printer_HPP_0DF65DD7_C97C_44ba_940D_D22ED6AF9494_
-#define INCG_IRIS_iutest_util_quiet_result_printer_HPP_0DF65DD7_C97C_44ba_940D_D22ED6AF9494_
+#ifndef INCG_IRIS_IUTEST_UTIL_QUIET_RESULT_PRINTER_HPP_0DF65DD7_C97C_44BA_940D_D22ED6AF9494_
+#define INCG_IRIS_IUTEST_UTIL_QUIET_RESULT_PRINTER_HPP_0DF65DD7_C97C_44BA_940D_D22ED6AF9494_
 
 //======================================================================
 // include
+
 namespace iuutil
 {
 
@@ -26,7 +25,7 @@ namespace iuutil
 // class
 
 /**
- * @brief	RpNgȃftHgR\[o̓CxgXi[
+ * @brief	コンパクトなデフォルトコンソール出力イベントリスナー
 */
 class QuietResultPrinter : public ::iutest::TestEventListener
 {
@@ -77,7 +76,7 @@ public:
 	{
 		if( test_info.result()->Failed() )
 		{
-			// sƂ̂ݏo͂
+			// 失敗したときのみ出力する
 			m_default_printer->OnTestEnd(test_info);
 		}
 	}
@@ -94,15 +93,25 @@ public:
 	virtual void OnTestProgramEnd(const ::iutest::UnitTest& unit_test) { m_default_printer->OnTestProgramEnd(unit_test); }
 private:
 	::iutest::TestEventListener* m_default_printer;
-};
 
-//! QuietResultPrinter ɐ؂ւ
-inline void SetUpQuietResultPrinter(void)
-{
-	::iutest::TestEventListeners& listeners = ::iutest::UnitTest::GetInstance()->listeners();
-	listeners.Append(new QuietResultPrinter(listeners.Release(listeners.default_result_printer())));
-}
+public:
+	/**
+	 * @brief	QuietResultPrinter に切り替え
+	*/
+	static ::iutest::TestEventListener* SetUp(void)
+	{
+		::iutest::TestEventListeners& listeners = ::iutest::UnitTest::GetInstance()->listeners();
+		::iutest::TestEventListener* default_printer = listeners.Release(listeners.default_result_printer());
+		if( default_printer == NULL )
+		{
+			return NULL;
+		}
+		::iutest::TestEventListener* p = new QuietResultPrinter(default_printer);
+		listeners.Append(p);
+		return p;
+	}
+};
 
 }	// end of namespace iuutil
 
-#endif
+#endif // INCG_IRIS_IUTEST_UTIL_QUIET_RESULT_PRINTER_HPP_0DF65DD7_C97C_44BA_940D_D22ED6AF9494_
