@@ -4,9 +4,7 @@
  * @file		iutest_printers_tests.cpp
  * @brief		iutest_printers.hpp テスト
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -18,9 +16,36 @@
 //======================================================================
 // include
 #include "../include/iutest.hpp"
+#include "iutest_logger_tests.hpp"
 
 #include <vector>
 
+#if !defined(IUTEST_USE_GTEST)
+TestLogger printer_logger;
+
+class LogChecker
+{
+	::std::string m_str;
+public:
+	LogChecker(const char* str) : m_str(str)
+	{
+		::iutest::detail::iuConsole::SetLogger(&printer_logger);
+	}
+	~LogChecker(void)
+	{
+		::iutest::detail::iuConsole::SetLogger(NULL);
+		IUTEST_EXPECT_STRIN(m_str.c_str(), printer_logger.c_str());
+		printer_logger.clear();
+	}
+};
+#else
+class LogChecker
+{
+public:
+	LogChecker(const char*) {}
+};
+#endif
+
 #ifdef UNICODE
 int wmain(int argc, wchar_t* argv[])
 #else
@@ -54,6 +79,7 @@ void PrintTo(const Bar& bar, ::iutest::iu_ostream* os)
 IUTEST(PrintToTest, Bar)
 {
 	Bar bar = {0, 1, 2};
+	LogChecker ck("x:0 y:1 z:2");
 	IUTEST_SUCCEED() << ::iutest::PrintToString(bar);
 }
 
@@ -111,8 +137,28 @@ IUTEST(PrintToTest, Std)
 	::std::pair<int, int> p(0, 1);
 	::std::vector<int> v(a, a+(sizeof(a)/sizeof(a[0])));
 
-	IUTEST_SUCCEED() << ::iutest::PrintToString(p);
-	IUTEST_SUCCEED() << ::iutest::PrintToString(v);
+	{
+		LogChecker ck("0, 1");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
+	{
+		LogChecker ck("{ 0, 1, 2 }");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(v);
+	}
+}
+
+IUTEST(PrintToTest, Null)
+{
+	{
+		LogChecker ck("(null)");
+		void* p = NULL;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
+	{
+		LogChecker ck("(null)");
+		void* p = NULL;
+		IUTEST_SUCCEED() << p;
+	}
 }
 
 #if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
@@ -125,19 +171,74 @@ IUTEST(PrintToTest, Iomanip)
 
 IUTEST(PrintToTest, WideString)
 {
-	IUTEST_SUCCEED() << ::iutest::PrintToString(L"Test");
+	{
+		LogChecker ck("Test");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(L"Test");
+	}
+	{
+		LogChecker ck("\\0");
+		wchar_t c = 0;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+	}
+//	{
+//		LogChecker ck("\'A\'");
+//		wchar_t c = L'A';
+//		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+//	}
+	{
+		LogChecker ck("(null)");
+		wchar_t* p = NULL;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
 }
 
-IUTEST(PrintToTest, UnicodeString)
+IUTEST(PrintToTest, String)
 {
-#if IUTEST_HAS_CHAR16_T
-	IUTEST_SUCCEED() << ::iutest::PrintToString(u"Test");
-#endif
-#if IUTEST_HAS_CHAR32_T
-	IUTEST_SUCCEED() << ::iutest::PrintToString(U"Test");
-#endif
+	{
+		LogChecker ck("Test");
+		IUTEST_SUCCEED() << ::iutest::PrintToString("Test");
+	}
+	{
+		LogChecker ck("\\0");
+		char c = 0;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+	}
+	{
+		LogChecker ck("\'A\'");
+		char c = 'A';
+		IUTEST_SUCCEED() << ::iutest::PrintToString(c);
+	}
+	{
+		LogChecker ck("(null)");
+		char* p = NULL;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
 }
 
+#if IUTEST_HAS_CHAR16_T
+IUTEST(PrintToTest, Unicode16String)
+{
+	IUTEST_SUCCEED() << ::iutest::PrintToString(u"Test");
+	{
+		LogChecker ck("(null)");
+		char16_t* p = NULL;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
+}
+#endif
+
+#if IUTEST_HAS_CHAR32_T
+IUTEST(PrintToTest, Unicode32String)
+{
+	IUTEST_SUCCEED() << ::iutest::PrintToString(U"Test");
+	{
+		LogChecker ck("(null)");
+		char32_t* p = NULL;
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p);
+	}
+}
+#endif
+
 struct Point0
 {
 	unsigned int x,y;
@@ -166,11 +267,49 @@ IUTEST(PrintToTest, Overload)
 	Point0 p0 = { 0x12345678, 0x9ABCDEF0 };
 	Point1 p1 = {0, 0};
 	Point2 p2 = {1, 1};
-	IUTEST_SUCCEED() << ::iutest::PrintToString(p0);
-	IUTEST_SUCCEED() << ::iutest::PrintToString(p1);
-	IUTEST_SUCCEED() << ::iutest::PrintToString(p2);
+	{
+		LogChecker ck("8-Byte object <");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p0);
+	}
+	{
+		LogChecker ck("(operator overload)");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p1);
+	}
+	{
+		LogChecker ck("(function overload)");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(p2);
+	}
 }
 
+struct Hoge {
+	int a[256];
+};
+IUTEST(PrintToTest, MaxElem)
+{
+	Hoge hoge;
+	{
+		LogChecker ck(" ...");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(hoge);
+	}
+	{
+		LogChecker ck(", ...");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(hoge.a);
+	}
+	{
+		::std::vector<int> v(hoge.a, hoge.a+256);
+		LogChecker ck(", ...");
+		IUTEST_SUCCEED() << ::iutest::PrintToString(v);
+	}
+}
+
+#if IUTEST_HAS_NULLPTR
+IUTEST(PrintToTest, Nullptr)
+{
+	LogChecker ck("nullptr");
+	IUTEST_SUCCEED() << ::iutest::PrintToString(nullptr);
+}
+#endif
+
 #if IUTEST_HAS_TUPLE
 IUTEST(PrintToTest, Tuple)
 {
