@@ -4,9 +4,7 @@
  * @file		iutest_record_property_tests.cpp
  * @brief		iutest RecordProperty 対応テスト
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2013-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -83,6 +81,10 @@ IUTEST_F(RecordTest, A)
 	IUTEST_EXPECT_NONFATAL_FAILURE( RecordProperty("value_param", "B"), "Reserved key");
 #endif
 	CheckProperty(::iutest::UnitTest::GetInstance()->current_test_info()->result(), "hoge", "B");
+	
+	// overwirte
+	RecordProperty("hoge", "b");
+	CheckProperty(::iutest::UnitTest::GetInstance()->current_test_info()->result(), "hoge", "b");
 }
 
 #endif
