@@ -4,9 +4,7 @@
  * @file		iutest_repeat_tests.cpp
  * @brief		繰り返し対応テスト
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -91,7 +89,7 @@ void CheckCount(int expected)
 bool RunTest(void)
 {
 	ClearCounter();
-	(void)IUTEST_RUN_ALL_TESTS();
+	if( IUTEST_RUN_ALL_TESTS() != 0 ) return false;
 	return ::iutest::UnitTest::GetInstance()->Passed();
 }
 
@@ -144,18 +142,18 @@ int main(int argc, char* argv[])
 #endif
 {
 	MyEnvironment* const env = new MyEnvironment();
-	IUTEST_ASSERT( ::iutest::AddGlobalTestEnvironment(env) == env );
+	IUTEST_ASSERT_EXIT( ::iutest::AddGlobalTestEnvironment(env) == env );
 	IUTEST_INIT(&argc, argv);
 	
-	IUTEST_ASSERT( RepeatTestUnspecified() );
-	IUTEST_ASSERT( RepeatTestNonFilter(0) );
-	IUTEST_ASSERT( RepeatTestNonFilter(2) );
-	IUTEST_ASSERT( RepeatTestNonFilter(10) );
+	IUTEST_ASSERT_EXIT( RepeatTestUnspecified() );
+	IUTEST_ASSERT_EXIT( RepeatTestNonFilter(0) );
+	IUTEST_ASSERT_EXIT( RepeatTestNonFilter(2) );
+	IUTEST_ASSERT_EXIT( RepeatTestNonFilter(10) );
 
-	IUTEST_ASSERT( RepeatTestWithEmpyFilter(2) );
-	IUTEST_ASSERT( RepeatTestWithEmpyFilter(3) );
+	IUTEST_ASSERT_EXIT( RepeatTestWithEmpyFilter(2) );
+	IUTEST_ASSERT_EXIT( RepeatTestWithEmpyFilter(3) );
 	
-	IUTEST_ASSERT( RepeatTestWithFilter(3) );
+	IUTEST_ASSERT_EXIT( RepeatTestWithFilter(3) );
 
 	printf("*** Successful ***\n");
 	return 0;
