@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_values_tests.cpp
- * @brief		iutest values test
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		Values test
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2013-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -25,7 +23,7 @@
 
 #define DECL_VALUES_PARAMS(i, param)	\
 	IUTEST_INSTANTIATE_TEST_CASE_P( IUTEST_PP_CAT(param,IUTEST_PP_INC(i)), ValuesTest	\
-			, ::iutest::Values( IUTEST_PP_ENUM_PARAMS(IUTEST_PP_INC(i), IUTEST_PP_EMPTY) ) );
+			, ::iutest::Values( IUTEST_PP_ENUM_PARAMS(IUTEST_PP_INC(i), IUTEST_PP_EMPTY()) ) );
 			
 #define DECL_VALUES_INSTANCE(n)			\
 	IUTEST_PP_REPEAT(n, DECL_VALUES_PARAMS, X)
@@ -40,7 +38,7 @@ IUTEST_P(ValuesTest, Test)
 
 IUTEST_INSTANTIATE_TEST_CASE_P( X1, ValuesTest, ::iutest::Values(1) );
 IUTEST_INSTANTIATE_TEST_CASE_P( X51, ValuesTest
-	, ::iutest::Values( IUTEST_PP_ENUM_PARAMS(51, IUTEST_PP_EMPTY) ) );
+	, ::iutest::Values( IUTEST_PP_ENUM_PARAMS(51, IUTEST_PP_EMPTY()) ) );
 
 #else
 
